@rem IBM Cognos 8 Special Edition - IBM DB2 Express Configuration Script C8SE_config_DB2-91.bat
@rem Copyright (C) 2008 Cognos ULC, an IBM Company. All rights reserved. 
@rem Cognos (R) is a trademark of Cognos ULC, (formerly Cognos Incorporated).
@echo on

set C8SE_DB2_Dst=[DB2_HOME]

@rem Setup common environment variables
set C8SE_scripts=%~dp0%

@rem Call the general environment setup script to set dynamic env vars
if EXIST "%C8SE_scripts%C8SE_env.bat" (
  call "%C8SE_scripts%C8SE_env.bat"
) else (
  @echo WARN Unable to load %C8SE_scripts%C8SE_env.bat
)

@rem Call the master environment setup script to set static env vars
if EXIST "%C8SE_scripts%C8SE_master_env.bat" (
  call "%C8SE_scripts%C8SE_master_env.bat"
) else (
  @echo WARN Unable to load %C8SE_scripts%C8SE_master_env.bat
)

@rem Set the log file name if not already set
if NOT DEFINED C8SE_logfile (
  set C8SE_logfile=%C8SE_scripts%C8SE_install.log
)

@rem Set the DB2 Version if not already set
if NOT DEFINED C8SE_DB2_Version (
  set C8SE_DB2_Version=DB2-91
)

@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Running IBM DB2 WSE configuration script (%0)>>"%C8SE_logfile%"

@rem Set the DB2 install path relative to the current directory
cd ..
cd /d %C8SE_scripts%

if EXIST "%C8SE_scripts%\C8SE_config_%C8SE_DB2_Version%.flg" (
  @echo %DATE% %TIME% WARN: %C8SE_DB2_Version%: IBM DB2 WSE configuration is being skipped>>"%C8SE_logfile%"
  goto exit
)

@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: IBM DB2 WSE will be configured in %C8SE_DB2_Dst%>>"%C8SE_logfile%"

@rem Ensure the DB2 executable is available
if NOT EXIST "%C8SE_DB2_Dst%\BIN\db2.exe" (
  @echo %DATE% %TIME% ERROR: %C8SE_DB2_Version%: File %C8SE_DB2_Dst%\BIN\db2.exe could not be located>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_DB2_Version%: File %C8SE_DB2_Dst%\BIN\db2.exe could not be located
  goto exit 
)

@rem Locate and set JAVA_HOME
if EXIST "%C8SE_WAS_Dst%\bin\setupCmdLine.bat" (
  call "%C8SE_WAS_Dst%\bin\setupCmdLine.bat"
)
if NOT DEFINED JAVA_HOME (
  if EXIST "%C8SE_C8_Dst%%C8SE_C8_JRE%" (
    set JAVA_HOME=%C8SE_C8_Dst%%C8SE_C8_JRE%
  )
)
if NOT DEFINED JAVA_HOME (
  @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: Unable to locate a suitable Java Runtime>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_DB2_Version%: Unable to locate a suitable Java Runtime
  goto exit 
)
if EXIST "%JAVA_HOME%\bin\java.exe" (
  set _JAVACMD=%JAVA_HOME%\bin\java.exe
) else (
  if EXIST "%JAVA_HOME%\jre\bin\java.exe" (
    set _JAVACMD=%JAVA_HOME%\jre\bin\java.exe
  ) else (
    @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: Unable to locate a suitable Java Runtime executable>>"%C8SE_logfile%"
    @echo FATAL: %C8SE_DB2_Version%: Unable to locate a suitable Java Runtime executable
    goto exit 
  )
)
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Using Java Runtime found in %JAVA_HOME%>>"%C8SE_logfile%"

set PATH=%PATH%;%C8SE_DB2_Dst%\bin

if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml" (
  @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_DB2_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located
  goto exit 
)

@rem Backup the existing configuration file if a backup does not already exist
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" (
  @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Backing up file %C8SE_C8_Dst%\configuration\cogstartup.xml>>"%C8SE_logfile%"
  copy /y "%C8SE_C8_Dst%\configuration\cogstartup.xml" "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" >>"%C8SE_logfile%" 2>>&1
)
@rem Verify the backup file is in place
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml.backup" (
  @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml.backup could not be created>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_DB2_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml.backup could not be created
  goto exit 
)

@rem Generate a new cogstartup.xml for DB2 using a transformation

@rem Setup the classpath to point to the Jar files we need for running the transformation on the cogstartup.xml file
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Setting transform classpath>>"%C8SE_logfile%"
if EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib" (
set _CLASSPATH=%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\jdxslt.jar;%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\xercesImpl.jar;%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\xml-apis.jar
)

@rem Setup some variables that will be used in the transformation on the cogstartup.xml file
set _SOURCEXML=%C8SE_C8_Dst%\configuration\cogstartup.xml
set _TARGETXML=%C8SE_C8_Dst%\configuration\cogstartup.C8SE.xml
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Setting source (%_SOURCEXML%) and target (%_TARGETXML%) for transform>>"%C8SE_logfile%"

@rem Replace the user token credentials in the xslt transformation file
if EXIST "%C8SE_scripts%C8SE_template_%C8SE_DB2_Version%.xslt" (
  @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Copying template to xslt file>>"%C8SE_logfile%"
  copy /y "%C8SE_scripts%C8SE_template_%C8SE_DB2_Version%.xslt" "%C8SE_scripts%C8SE_config_%C8SE_DB2_Version%.xslt" >>"%C8SE_logfile%" 2>>&1
)
if NOT EXIST "%C8SE_scripts%C8SE_config_%C8SE_DB2_Version%.xslt" (
  @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: File %C8SE_scripts%C8SE_config_%C8SE_DB2_Version%.xslt could not be created>>"%C8SE_logfile%"
  goto exit
)
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Setting user credentials in xslt file>>"%C8SE_logfile%"
if DEFINED C8SE_C8_DB_UID (
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_Config_%C8SE_DB2_Version%.xslt" "<username>" "</username>" "<username>%C8SE_C8_DB_UID%" >>"%C8SE_logfile%" 2>>&1
)
if DEFINED C8SE_C8_DB_Pass (
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_Config_%C8SE_DB2_Version%.xslt" "<password>" "</password>" "<password>%C8SE_C8_DB_Pass%" >>"%C8SE_logfile%" 2>>&1
)

if DEFINED C8SE_C8_DB_Name (
  @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Modifying Database Name to %C8SE_C8_DB_Name%>>"%C8SE_logfile%"
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_Config_%C8SE_DB2_Version%.xslt" "C8SE_C8_DB_Name" "%C8SE_C8_DB_Name%" >>"%C8SE_logfile%" 2>>&1
) else (
  @echo %DATE% %TIME% INFO: %C8SE_C8_Version%: Setting Database Name to default>>"%C8SE_logfile%"
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_Config_%C8SE_DB2_Version%.xslt" "C8SE_C8_DB_Name" "CM" >>"%C8SE_logfile%" 2>>&1
)

if DEFINED C8SE_DB2_Port (
  @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Setting Port Number to %C8SE_DB2_Port%>>"%C8SE_logfile%"
  "%C8SE_scripts%%C8SE_replace_tool%" "%C8SE_scripts%C8SE_Config_%C8SE_DB2_Version%.xslt" "C8SE_DB2_Port" "%C8SE_DB2_Port%" >>"%C8SE_logfile%" 2>>&1
)


@rem Use the C8SE_Config_DB2-91.xslt transformation to replace the Content Store database section of the startup file
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Running xslt transformation command>>"%C8SE_logfile%"
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Java Command: "%_JAVACMD%" -cp "%_CLASSPATH%" jd.xml.xslt.Stylesheet -OUT "%_TARGETXML%" "%_SOURCEXML%" "%C8SE_scripts%C8SE_Config_%C8SE_DB2_Version%.xslt">>"%C8SE_logfile%"

"%_JAVACMD%" -cp "%_CLASSPATH%" jd.xml.xslt.Stylesheet -OUT "%_TARGETXML%" "%_SOURCEXML%" "%C8SE_scripts%C8SE_config_%C8SE_DB2_Version%.xslt">>"%C8SE_logfile%" 2>>&1

@rem Save the original cogstartup file and replace with the new one that was transformed
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Renaming of cogstartup.xml file after transformation>>"%C8SE_logfile%"
if EXIST "%_SOURCEXML%" (
  @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Creating a backup of %_SOURCEXML%>>"%C8SE_logfile%"
  copy /y "%_SOURCEXML%" "%C8SE_C8_Dst%\configuration\cogstartup.backup.xml" >>"%C8SE_logfile%" 2>>&1
) else (
  @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: File %_SOURCEXML% could not be located>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_DB2_Version%: Source file %_SOURCEXML% could not be located
  goto exit
)
if EXIST "%C8SE_C8_Dst%\configuration\cogstartup.backup.xml" (
  if EXIST "%_TARGETXML%" (
    @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Replacing %_SOURCEXML% with %_TARGETXML%>>"%C8SE_logfile%"
    copy /y "%_TARGETXML%" "%_SOURCEXML%" >>"%C8SE_logfile%" 2>>&1
  ) else (
    @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: File %_TARGETXML% could not be located>>"%C8SE_logfile%"
    @echo FATAL: %C8SE_DB2_Version%: Target file %_TARGETXML% could not be located
    goto exit
  )
)

@rem Verify cogstartup.xml is in place after manipulation
if NOT EXIST "%C8SE_C8_Dst%\configuration\cogstartup.xml" (
  @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_DB2_Version%: File %C8SE_C8_Dst%\configuration\cogstartup.xml could not be located
  goto exit 
)

@rem Copy the DB2 JDBC Driver to the proper location
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Copy db2java.jar to the web applications folder>>"%C8SE_logfile%"
if EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib" (
  if EXIST "%C8SE_DB2_Dst%\java\db2java.jar" (
    copy /y "%C8SE_DB2_Dst%\java\db2java.jar" "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\db2java.jar" >>"%C8SE_logfile%" 2>>&1
  )
  if EXIST "%C8SE_DB2_Dst%\java\db2java.zip" (
    copy /y "%C8SE_DB2_Dst%\java\db2java.zip" "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\db2java.jar" >>"%C8SE_logfile%" 2>>&1
  )
)
if NOT EXIST "%C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\db2java.jar" (
  @echo %DATE% %TIME% FATAL: %C8SE_DB2_Version%: Unable to create or copy %C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\db2java.jar>>"%C8SE_logfile%"
  @echo FATAL: %C8SE_DB2_Version%: Unable to create %C8SE_C8_Dst%\webapps\p2pd\WEB-INF\lib\db2java.jar
  goto exit 
)

if NOT EXIST "%C8SE_scripts%\C8SE_config_%C8SE_DB2_Version%.flg" (
  @echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Creating flag on successful configuration >>"%C8SE_logfile%"
  @echo %DATE% %TIME% %C8SE_DB2_Version% >"%C8SE_scripts%\C8SE_config_%C8SE_DB2_Version%.flg"
)

:exit
@rem Return to original location
@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Changing directories to %C8SE_scripts%>>"%C8SE_logfile%"
cd /d %C8SE_scripts%

@echo %DATE% %TIME% INFO: %C8SE_DB2_Version%: Exiting IBM DB2 WSE configuration script>>"%C8SE_logfile%"

@rem *****************
@rem * End of Script *
@rem *****************